@@ -6,7 +6,7 @@ from .base_document import BaseDocument
 
 class ShoppingListItem(mongo.EmbeddedDocument):
     checked = mongo.BooleanField(required=True)
-    item = mongo.ReferenceField('Ingredient', required=True)
+    item = mongo.ReferenceField('Ingredient')
     name = mongo.StringField(required=True)
     supermarketSectionName = mongo.StringField()
     listPosition = mongo.IntField(min_value=0)
