@@ -8,6 +8,10 @@ class SupermarketSection(mongo.EmbeddedDocument):
     name = mongo.StringField(max_length=MAX_SECTION_NAME_LENGTH, required=True)
     color = mongo.IntField(max_length=MAX_SECTION_NAME_LENGTH)
 
+    meta = {
+        'strict': False
+    }
+
 
 class UserPreferences(BaseDocument):
     supermarket_sections = mongo.EmbeddedDocumentListField(
@@ -19,8 +23,7 @@ class UserPreferences(BaseDocument):
         mongo.StringField(min_value=1, max_value=10), default=None)
 
     meta = {
-        'collection': 'user_preferences',
-        'strict': False
+        'collection': 'user_preferences'
     }
 
     def __repr__(self):
