@@ -8,6 +8,7 @@ def create_module(app, api):
     from .auth import create_module as create_auth_module
     from .scrapers import create_module as create_scrapers_module
     from .ingredients import create_module as create_ingredients_module
+    from .ingredients_view import create_module as create_ingredients_view_module
     from .menu import create_module as create_menu_module
     from .recipes import create_module as create_recipes_module
     from .users import create_module as create_users_module
@@ -19,6 +20,7 @@ def create_module(app, api):
     create_scrapers_module(app)
 
     create_ingredients_module(app, api)
+    create_ingredients_view_module(app, api)
     create_menu_module(app, api)
     create_recipes_module(app, api)
     create_users_module(app, api)
